@@ -7,7 +7,7 @@ use warnings;
 
 use Carp;
 
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 
 sub import {
     return;
@@ -87,7 +87,8 @@ L<Games::Sudoku::General|Games::Sudoku::General>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Games-Sudoku-General/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -95,7 +96,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2019 by Thomas R. Wyant, III
+Copyright (C) 2016-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
