@@ -50,7 +50,7 @@ what solution constraints were applied, what cell each constraint
 is applied to, and what symbol the cell was constrained to.
 
 Test script t/sudoku.t demonstrates these features. ActivePerl users
-will have to download the kit from L<http://www.cpan.org/>  or
+will have to download the kit from L<https://www.cpan.org/>  or
 L<https://metacpan.org/release/Games-Sudoku-General> to get this
 file.
 
@@ -396,7 +396,7 @@ on output. The default is a single space.
 
 This "virtual" attribute is a convenience, which causes the object to be
 configured as a quincunx (a. k. a. 'Samurai Sudoku' at
-L<http://www.samurai-sudoku.com/>). The value must be
+L<https://www.samurai-sudoku.com/>). The value must be
 either a comma-separated list of one to two numbers (e.g. '3,1') or a
 reference to a list of one to two numbers (e.g. [3, 1]). In either case,
 the numbers are the order of the quincunx (3 corresponding to the usual
@@ -576,7 +576,7 @@ use warnings;
 
 use Exporter qw{ import };
 
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 our @EXPORT_OK = qw{
     SUDOKU_SUCCESS
     SUDOKU_NO_SOLUTION
@@ -1669,9 +1669,11 @@ element is the name of the constraint applied:
      in the tuple are supressed.
  ? = no constraint: generated in backtrack mode.
 
-See L<http://www.research.att.com/~gsf/sudoku/> and
+See C<http://www.research.att.com/~gsf/sudoku/> and
 L<http://www.angusj.com/sudoku/hints.php> for fuller
-definitions of the constraints and how they are applied.
+definitions of the constraints and how they are applied. The
+L<ACKNOWLEDGMENTS|/ACKNOWLEDGMENTS> section addresses why the former
+URL is not an actual POD link.
 
 The second value is the cell number, as defined by the topology
 setting. For the 'sudoku' and 'latin' settings, the cells are
@@ -2455,19 +2457,23 @@ The X, Y, and W constraints (to use Glenn Fowler's terminology) are
 not yet handled. The package can solve puzzles that need these
 constraints, but it does so by backtracking.
 
-Please report bugs either through L<http://rt.cpan.org/> or by
-mail to the author.
+Please report bugs either through
+L<https://github.com/trwyant/perl-Games-Sudoku-General/issues/> or by
+electronic mail to the author.
 
 =head1 ACKNOWLEDGMENTS
 
 The author would like to acknowledge the following, without whom this
 module would not exist:
 
-Glenn Fowler of AT&T, whose L<http://www.research.att.com/~gsf/sudoku/>
-provided the methodological starting point and basic terminology, whose
-'sudoku' executable provided a reference implementation for checking
-the solutions of standard Sudoku puzzles, and whose constraint taxonomy
-data set provided invaluable test data.
+Glenn Fowler, formerly of AT&T, whose
+C<http://www.research.att.com/~gsf/sudoku/> provided the methodological
+starting point and basic terminology, whose 'sudoku' executable provided
+a reference implementation for checking the solutions of standard Sudoku
+puzzles, and whose constraint taxonomy data set provided invaluable test
+data. Dr. Fowler has left AT&T, and the above link is no longer valid,
+but is retained for documentation, and for use in (e.g.) the Wayback
+Machine. Some of the material is available at L<http://gsf.cococlyde.org/>.
 
 Angus Johnson, whose fulsome explanation at
 L<http://www.angusj.com/sudoku/hints.php> was a great help
@@ -2481,7 +2487,7 @@ provided a treasure trove of 'non-standard' Sudoku puzzles.
 =head1 SEE ALSO
 
 The C<Games-LogicPuzzle> package by Andy Adler (see
-L<http://metacpan.org/release/Games-LogicPuzzle/>) solves all sorts of
+L<https://metacpan.org/release/Games-LogicPuzzle>) solves all sorts of
 combinatorial puzzles, by backtracking through the puzzle space and
 applying a user-supplied function to see whether it has a valid
 solution. The examples include a couple Sudoku puzzles.
@@ -2492,11 +2498,11 @@ version of the puzzle. As of June 15 2019 this appears to have been
 retracted.
 
 The C<Games-Sudoku-Component> package by Kenichi Ishigaki (see
-L<http://metacpan.org/release/Games-Sudoku-Component/>) both
+L<https://metacpan.org/release/Games-Sudoku-Component>) both
 generates and solves the standard 9x9 version of the puzzle.
 
 The C<Games-Sudoku-Component-TkPlayer> by Kenichi Ishigaki (see
-L<http://metacpan.org/release/Games-Sudoku-Component-TkPlayer/>). Tk
+L<https://metacpan.org/release/Games-Sudoku-Component-TkPlayer>). Tk
 front end for his Games-Sudoku-Component.
 
 The C<Games-Sudoku-CPSearch> package by Martin-Louis Bright (see
@@ -2504,25 +2510,25 @@ L<https://metacpan.org/release/Games-Sudoku-CPSearch>). Solves 9x9
 Sudoku by use of "F" and "N" constraints and backtracking.
 
 The C<Games-Sudoku-Lite package> by Bob O'Neill (see
-L<http://metacpan.org/release/Games-Sudoku-Lite/>) solves the standard
+L<https://metacpan.org/release/Games-Sudoku-Lite>) solves the standard
 9x9 version of the puzzle.
 
 The C<Games-Sudoku-OO> package by Michael Cope (see
-L<http://metacpan.org/release/Games-Sudoku-OO/>) also solves the
+L<https://metacpan.org/release/Games-Sudoku-OO>) also solves the
 standard 9x9 version of the puzzle, with an option to solve (to the
 extent possible) a single row, column, or square. The implementation may
 be extensible to other topologies than the standard one.
 
 The C<Games-Sudoku-Solver> package by Fritz Mehner (see
-L<http://metacpan.org/release/Games-Sudoku-Solver/>) solves 9x9 Sudoku
+L<https://metacpan.org/release/Games-Sudoku-Solver>) solves 9x9 Sudoku
 puzzles by recursion and backtracking.
 
 The C<Games-Sudoku-SudokuTk> package by Christian Guine (see
-L<http://metacpan.org/release/Games-Sudoku-SudokuTk/> claims to
+L<https://metacpan.org/release/Games-Sudoku-SudokuTk> claims to
 implement a Tk-based Sudoku solver.
 
 The C<Games-YASudoku> package by Andrew Wyllie (see
-L<http://metacpan.org/release/Games-YASudoku/>) also solves the standard
+L<https://metacpan.org/release/Games-YASudoku>) also solves the standard
 9x9 version of the puzzle. In contrast to the other packages, this one
 represents the board as a list of cell/value pairs.
 
@@ -2532,7 +2538,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2006, 2008, 2011-2019 by Thomas R. Wyant, III
+Copyright (C) 2005-2006, 2008, 2011-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
